@@ -2,15 +2,13 @@ use std::{pin::Pin, sync::Arc, task::{Context, Poll, Waker}};
 use crossbeam::channel::{Receiver, Sender, unbounded};
 use futures::Stream;
 use parking_lot::RwLock;
-use xecs::{component::Component, entity::EntityId, system::System, world::World};
+use xecs::{entity::EntityId, system::System, world::World};
 
 pub(in crate) struct LeaveFrameInner {
     pub(in crate) tx : Sender<u32>,
     pub(in crate) waker : Waker
 }
 
-impl Component for LeaveFrameInner {}
-
 pub struct LeaveFrame {
     world : Arc<RwLock<World>>,
     rx : Option<(EntityId,Receiver<u32>)>
